[Libreoffice-commits] core.git: toolkit/source

Libreoffice Gerrit user logerrit at kemper.freedesktop.org
Wed Feb 6 10:23:58 UTC 2019


 toolkit/source/controls/tabpagemodel.cxx |    5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

New commits:
commit 24e7d98219191ccdab3673ac96fa866c449cac5f
Author:     Vasily Melenchuk <vasily.melenchuk at cib.de>
AuthorDate: Wed Feb 6 00:41:25 2019 +0300
Commit:     Michael Stahl <Michael.Stahl at cib.de>
CommitDate: Wed Feb 6 11:23:34 2019 +0100

    basic: fix for UnoControlTabPageModel get/set properties
    
    The userformscontainers is required property to pass checks in
    getter/setter, but returning true instead of actual type is
    not a best idea. So let's return actually expected dummy empty
    container.
    
    Change-Id: I5cc3e5462ed82f6f2f8e5a45d9fc2d9f9ce1c76f
    Reviewed-on: https://gerrit.libreoffice.org/67431
    Tested-by: Jenkins
    Reviewed-by: Michael Stahl <Michael.Stahl at cib.de>

diff --git a/toolkit/source/controls/tabpagemodel.cxx b/toolkit/source/controls/tabpagemodel.cxx
index 85f7347c4038..738b526568b3 100644
--- a/toolkit/source/controls/tabpagemodel.cxx
+++ b/toolkit/source/controls/tabpagemodel.cxx
@@ -86,9 +86,10 @@ Any UnoControlTabPageModel::ImplGetDefaultValue( sal_uInt16 nPropId ) const
             break;
         case BASEPROPERTY_USERFORMCONTAINEES:
         {
             // We do not have here any usercontainers (yet?), but let's return something back
             // so normal properties could be set without triggering UnknownPropertyException
-            return makeAny(true);
+            aAny <<= uno::Reference< XNameContainer >();
+            break;
         }
         default:
             aAny = UnoControlModel::ImplGetDefaultValue( nPropId );
@@ -86,9 +86,10 @@ Any UnoControlTabPageModel::ImplGetDefaultValue( sal_uInt16 nPropId ) const
         case BASEPROPERTY_USERFORMCONTAINEES:
         {
-            // We do not have here any usercontainers (yet?), but let's return something back
+            // We do not have here any usercontainers (yet?), but let's return empty container back
             // so normal properties could be set without triggering UnknownPropertyException


More information about the Libreoffice-commits mailing list